@@ -221,7 +221,6 @@ class FBII(SerialBase):
     coupon_printer_charset = "ascii"
 
     def __init__(self, port, consts=None):
-        port.set_options(baudrate=38400)
         SerialBase.__init__(self, port)
         self._consts = consts or FBIIConstants
         self._command_id = FIRST_COMMAND_ID-1 #0x80
@@ -394,7 +393,7 @@ class FBII(SerialBase):
         reply = self._send_command('080A')
         # Data de abertura.
         date = reply.fields[0]
-        d, m, y = map(int, [date[:2], date[3:4], date[4:8]])
+        d, m, y = map(int, [date[:2], date[2:4], date[4:8]])
         opening_date = datetime.date(y, m, d)
         # COO inicial.
         coupon_start = int(reply.fields[4])
@@ -543,7 +542,8 @@ class FBII(SerialBase):
                                self._customer_address[41:79])
             self._reset()
 
-        reply = self._send_command('0A06', '0000')
+        reply = self._send_command('0A06', '0001')
+        self._send_command('0702', '0000')
         return int(reply.fields[0])
 
     def gerencial_report_open(self):
